Module bin_links

Module bin_links 

Structs

LinkConflict
LinkReport
LinkSpec
UnlinkReport

Enums

LinkConflictKind
LinkRuntime
Runtime used to invoke a linked command.

Functions

command_path_for_name
link_executables_with_names
link_stem
unlink_managed
Remove symlinks in bin_dir whose link target starts with managed_root.
unlink_managed_command
Remove one command entry only when it is owned by Shine and points below one of managed_roots. This is the command-scoped counterpart to unlink_managed; foreign files and links are reported as skipped.