Bridge modules for interoperability with other version control systems.
This module provides bidirectional conversion between Heddle and other VCS, starting with Git support.
Re-exports
pub use git_core::GitBridge;pub use git_core::GitBridgeError;pub use git_core::GitResult;pub use git_core::SyncMapping;pub use git_core::WriteThroughOutcome;pub use git_core::WriteThroughSkipReason;
Modules
- git_
core - Core Git bridge types and operations.
- git_
export - Export Heddle states to Git commits functionality.
- git_
mapping - Persistence and discovery for Git bridge mappings.
- git_
notes - Git notes attached at
refs/notes/heddlecarry Heddle state metadata (change_id, agent, confidence, status) without polluting the commit message — and so without changing the commit SHA. - git_
reconstruct - Byte-exact git commit object serialization from a Heddle
State(#566). - git_
sync - Sync threads/markers functionality for Git bridge.
- git_
util - Shared utilities and helpers for Git bridge operations.