pub fn export_current_thread(
bridge: &mut GitBridge<'_>,
thread: &str,
) -> GitResult<ExportStats>Expand description
Export one Heddle thread to its matching Git branch.
pub fn export_current_thread(
bridge: &mut GitBridge<'_>,
thread: &str,
) -> GitResult<ExportStats>Export one Heddle thread to its matching Git branch.