pub enum RedactTrustCommands {
Add(RedactTrustAddArgs),
List(RedactTrustListArgs),
Remove(RedactTrustRemoveArgs),
}Variants
Add(RedactTrustAddArgs)
Add an operator public key to [redact] trusted_keys in
.heddle/config.toml. Subsequent heddle fetch/clone
invocations will accept signed redactions from that key.
List(RedactTrustListArgs)
List the currently-trusted operator keys.
Remove(RedactTrustRemoveArgs)
Remove an operator public key from the trust list. Future signed redactions from that key will be refused.