pub struct AgentFanoutPlanArgs {
pub title: String,
pub lane: Vec<String>,
pub coordination_discussion_id: Option<String>,
}Expand description
Arguments shared by agent fanout plan and agent fanout start.
Fields
title: StringParent coordination task title.
lane: Vec<String>Lane spec: <thread>=<path>:<title>. Repeat once per child lane.
coordination_discussion_id: Option<String>Optional collaboration discussion id to store on task assignments.