pub struct AgentTaskCreateArgs {
pub task_id: Option<String>,
pub title: String,
pub body: Option<String>,
pub thread: String,
pub base_state: Option<String>,
pub base_root: Option<String>,
pub parent_task_id: Option<String>,
pub coordination_discussion_id: Option<String>,
pub allow_offline: bool,
pub delegated_by: Option<String>,
}Expand description
Arguments for agent task create.
Fields
task_id: Option<String>Optional caller-provided task id (default: generated task UUIDv7 id).
title: StringHuman-readable task title.
body: Option<String>Detailed task body.
thread: StringThread this task targets.
base_state: Option<String>Optional base state id this task was delegated from.
base_root: Option<String>Optional base root id this task was delegated from.
parent_task_id: Option<String>Optional parent task id.
coordination_discussion_id: Option<String>Optional coordination discussion id.
allow_offline: boolAllow this task to continue without hosted connectivity.
delegated_by: Option<String>Principal or agent that delegated this task.