cmd_collapse

Function cmd_collapse 

pub fn cmd_collapse(
    cli: &Cli,
    states: Vec<String>,
    into: String,
    confidence: Option<f32>,
) -> Result<()>
Collapse (squash) multiple states into a single state.

The resulting state has:

  • The tree from the last state in the sequence
  • The parents of the first state in the sequence
  • A new intent (from –into) summarizing the collapsed work
  • A new confidence (optional)

This is useful for cleaning up exploratory work before sharing.