pub struct AvailableGitRefSchema {
pub name: String,
pub git_commit: String,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
}Fields
name: Stringgit_commit: Stringrecommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>Trait Implementations
Sourceimpl Debug for AvailableGitRefSchema
impl Debug for AvailableGitRefSchema
Sourceimpl JsonSchema for AvailableGitRefSchema
impl JsonSchema for AvailableGitRefSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AvailableGitRefSchema
impl Serialize for AvailableGitRefSchema
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more