pub struct BlameOriginSchema {
pub state_id: String,
pub principal: BlamePrincipalSchema,
pub agent: Option<BlameAgentSchema>,
pub timestamp: String,
}Fields
state_id: Stringprincipal: BlamePrincipalSchemaagent: Option<BlameAgentSchema>timestamp: StringTrait Implementations
Sourceimpl Debug for BlameOriginSchema
impl Debug for BlameOriginSchema
Sourceimpl JsonSchema for BlameOriginSchema
impl JsonSchema for BlameOriginSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for BlameOriginSchema
impl Serialize for BlameOriginSchema
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more