pub struct LandBatchPeerSchema {Show 14 fields
pub thread: String,
pub status: String,
pub message: String,
pub captured: bool,
pub checkpointed: bool,
pub git_commit: Option<String>,
pub integrated: bool,
pub synced: bool,
pub siblings_restacked: Vec<String>,
pub siblings_restack_failed: Vec<SiblingRestackFailureSchema>,
pub blockers: Vec<String>,
pub warnings: Vec<String>,
pub primary_command: Option<String>,
pub recovery_commands: Vec<String>,
}Fields
thread: Stringstatus: Stringmessage: Stringcaptured: boolcheckpointed: boolgit_commit: Option<String>integrated: boolsynced: boolsiblings_restacked: Vec<String>siblings_restack_failed: Vec<SiblingRestackFailureSchema>blockers: Vec<String>warnings: Vec<String>primary_command: Option<String>recovery_commands: Vec<String>Trait Implementations
Sourceimpl Debug for LandBatchPeerSchema
impl Debug for LandBatchPeerSchema
Sourceimpl JsonSchema for LandBatchPeerSchema
impl JsonSchema for LandBatchPeerSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for LandBatchPeerSchema
impl Serialize for LandBatchPeerSchema
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more