pub struct SyncGitSchema {
pub output_kind: Option<String>,
pub status: String,
pub action: Option<String>,
pub summary: String,
pub states_exported: u64,
pub commits_exported_total: u64,
pub commits_imported: u64,
pub threads_synced: u64,
pub markers_synced: u64,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub recovery_commands: Vec<String>,
}Fields
output_kind: Option<String>status: Stringaction: Option<String>summary: Stringstates_exported: u64commits_exported_total: u64commits_imported: u64threads_synced: u64markers_synced: u64recommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>recovery_commands: Vec<String>Trait Implementations
Sourceimpl Debug for SyncGitSchema
impl Debug for SyncGitSchema
Sourceimpl JsonSchema for SyncGitSchema
impl JsonSchema for SyncGitSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for SyncGitSchema
impl Serialize for SyncGitSchema
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more