pub struct ThreadMarkerEntrySchema {
pub name: String,
pub state_id: String,
}Fields
name: Stringstate_id: StringTrait Implementations
Sourceimpl Debug for ThreadMarkerEntrySchema
impl Debug for ThreadMarkerEntrySchema
Sourceimpl JsonSchema for ThreadMarkerEntrySchema
impl JsonSchema for ThreadMarkerEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ThreadMarkerEntrySchema
impl Serialize for ThreadMarkerEntrySchema
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more