pub struct UndoSchema {
pub output_kind: Option<String>,
pub status: Option<String>,
pub action: String,
pub message: String,
pub batches: Vec<Value>,
pub next_action: Option<String>,
pub next_action_template: Option<ActionTemplateSchema>,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub recovery_state: Option<String>,
pub recovery_marker: Option<String>,
}Fields
output_kind: Option<String>status: Option<String>action: Stringmessage: Stringbatches: Vec<Value>next_action: Option<String>next_action_template: Option<ActionTemplateSchema>recommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>recovery_state: Option<String>The checkout-local state preserved for recovery, and its internal handle. Present on completed undo and recovery operations.
recovery_marker: Option<String>Trait Implementations
Sourceimpl Debug for UndoSchema
impl Debug for UndoSchema
Sourceimpl JsonSchema for UndoSchema
impl JsonSchema for UndoSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for UndoSchema
impl Serialize for UndoSchema
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more