pub fn worktree_status_options(config: Option<&Config>) -> WorktreeStatusOptionsExpand description
Resolve worktree status options from user, repo, and env config.
pub fn worktree_status_options(config: Option<&Config>) -> WorktreeStatusOptionsResolve worktree status options from user, repo, and env config.