pub async fn push_context(
repo: &Repository,
client: &mut HostedGrpcClient,
repo_path: &str,
) -> Result<usize>Expand description
Publish local annotations we authored to the hosted RepositoryService.
pub async fn push_context(
repo: &Repository,
client: &mut HostedGrpcClient,
repo_path: &str,
) -> Result<usize>Publish local annotations we authored to the hosted RepositoryService.