Module command

Module command 

Re-exports

pub use algorithm::*;
pub use cache::*;
pub use certificate::*;
pub use common::*;
pub use convert::*;
pub use create::*;
pub use create_primary::*;
pub use delete::*;
pub use evict::*;
pub use load::*;
pub use memory::*;
pub use pcr_event::*;
pub use policy::*;
pub use reset_lock::*;
pub use return_code::*;
pub use unseal::*;

Modules

algorithm
cache
certificate
common
convert
create
Handles the create command, which creates secondary keys or sealed objects.
create_primary
delete
evict
load
memory
pcr_event
policy
reset_lock
return_code
unseal

Enums

CommandError

Traits

Tabled
A trait for data structures that can be represented as a table row.

Functions

deny_keyedhash
Returns an error if the provided algorithm is KeyedHash.
print_table
Creates, styles, and prints a table from a vector of Tabled items.