pub struct InputOptions {
pub passed_as_input: bool,
}Expand description
Extra metadata attached to an input by some commander callbacks.
Fields
passed_as_input: boolTrait Implementations
Sourceimpl Clone for InputOptions
impl Clone for InputOptions
Sourcefn clone(&self) -> InputOptions
fn clone(&self) -> InputOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputOptions
impl Debug for InputOptions
Sourceimpl PartialEq for InputOptions
impl PartialEq for InputOptions
Sourcefn eq(&self, other: &InputOptions) -> bool
fn eq(&self, other: &InputOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for InputOptions
impl StructuralPartialEq for InputOptions