pub enum SysCommands {
List {
all: bool,
},
Info {
item: String,
},
Status,
Update {
item: Option<String>,
verbose: bool,
proxy: bool,
},
Bootstrap {
preset: Option<String>,
dry_run: bool,
force_profile: bool,
proxy: bool,
},
Apply {
item: Option<String>,
dry_run: bool,
},
Uninstall {
item: String,
dry_run: bool,
},
}Variants
List
List available system items
Info
Show detailed information about a system item
Status
Show system bootstrap items previously initialized by shine
Update
Check recorded bootstrap software for updates without upgrading it
Fields
Bootstrap
Bootstrap software and shell integration for the current OS
Fields
Apply
Reapply enabled managed system configuration items
Fields
Uninstall
Remove a managed system configuration item safely