load_command_invocation

Function load_command_invocation 

pub fn load_command_invocation<I, S>(
    args: I,
) -> Result<ActionInvocation, CommandParseError>
where I: IntoIterator<Item = S>, S: AsRef<str>,
Pure equivalent of upstream CommandLoader.load: resolve one command line into the action invocation that would be handed to an action, without executing the action or touching process state.