pub struct CommandArgumentSpec {
pub name: &'static str,
pub arity: ArgumentArity,
}Expand description
A positional argument declared by an upstream command signature.
Fields
name: &'static strarity: ArgumentArityTrait Implementations
Sourceimpl Clone for CommandArgumentSpec
impl Clone for CommandArgumentSpec
Sourcefn clone(&self) -> CommandArgumentSpec
fn clone(&self) -> CommandArgumentSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandArgumentSpec
impl Debug for CommandArgumentSpec
Sourceimpl PartialEq for CommandArgumentSpec
impl PartialEq for CommandArgumentSpec
Sourcefn eq(&self, other: &CommandArgumentSpec) -> bool
fn eq(&self, other: &CommandArgumentSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for CommandArgumentSpec
impl Eq for CommandArgumentSpec
impl StructuralPartialEq for CommandArgumentSpec