pub struct CommandOptionSpec {
pub short: Option<char>,
pub long: &'static str,
pub input_name: &'static str,
pub value_kind: OptionValueKind,
pub default: OptionDefault,
pub negates: Option<&'static str>,
}Expand description
Data-only descriptor for a command option and its mapped action input name.
Fields
short: Option<char>long: &'static strinput_name: &'static strvalue_kind: OptionValueKinddefault: OptionDefaultnegates: Option<&'static str>Trait Implementations
Sourceimpl Clone for CommandOptionSpec
impl Clone for CommandOptionSpec
Sourcefn clone(&self) -> CommandOptionSpec
fn clone(&self) -> CommandOptionSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandOptionSpec
impl Debug for CommandOptionSpec
Sourceimpl PartialEq for CommandOptionSpec
impl PartialEq for CommandOptionSpec
Sourcefn eq(&self, other: &CommandOptionSpec) -> bool
fn eq(&self, other: &CommandOptionSpec) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for CommandOptionSpec
impl Eq for CommandOptionSpec
impl StructuralPartialEq for CommandOptionSpec