pub struct EnvProxyRule {
pub command: String,
pub with: Vec<String>,
pub enabled: bool,
}Expand description
A command whose protected environment values are injected by a shine proxy.
Fields
command: Stringwith: Vec<String>enabled: boolWhether the proxy injects its configured values. Disabled proxies still forward to their recorded target without resolving any secret.