Module convert

Module convert 

Functions

from_input_to_bytes
Reads data from a file path or from stdin if the path is not provided.
from_str_to_alg
Parses a string into an Alg for a sealed object.
from_str_to_handle
Parses a 16 character hex string with an optional 0x prefix into TpmHandle.
from_str_to_tpm_rc
Parses a string into a TpmRc.
from_tpm_key_to_output
Handles the output logic for a command that produces a TpmKey.
from_tpm_object_to_vec
A helper to build a TpmBuild type into a Vec<u8>.