Module crypto

Module crypto 

This file contains cryptographic algorithms shared by tpm2sh and MockTPM.

Enums

CryptoError

Constants

KDF_LABEL_DUPLICATE
KDF_LABEL_INTEGRITY
KDF_LABEL_STORAGE
UNCOMPRESSED_POINT_TAG

Functions

crypto_digest
Computes a cryptographic digest over a series of data chunks.
crypto_ecdh_p256
crypto_ecdh_p384
crypto_ecdh_p521
crypto_hmac
Computes an HMAC digest over a series of data chunks.
crypto_hmac_verify
Verifies an HMAC signature over a series of data chunks.
crypto_kdfa
Implements the KDFa key derivation function from the TPM specification.
crypto_kdfe
Implements the KDFe key derivation function from SP 800-56A for ECDH.
crypto_make_name
Calculates the TPM name of a public object.
derive_seed_with_ecc
Derives a seed and an ephemeral public key using ECDH with the parent’s ECC public key.
protect_seed_with_rsa
Encrypts a seed using the parent’s RSA public key for duplication.