Module device

Module device 

Structs

Device

Enums

Auth
Represents an authorization method for a command.
DeviceError

Constants

TPM_CAP_PROPERTY_MAX

Traits

TpmCommandObject
A type-erased object safe TPM command object

Functions

with_device
Executes a closure with a mutable reference to a Device.

Type Aliases

AuthList
A type alias for a list of authentications, to attach methods.