pub struct Device { /* private fields */ }Implementations
Sourceimpl Device
impl Device
Sourcepub fn new(file: File, log_format: LogFormat) -> Result<Self, DeviceError>
pub fn new(file: File, log_format: LogFormat) -> Result<Self, DeviceError>
Creates a new TPM device from an owned transport.
Errors
Returns an error if the system poller cannot be created.
Sourcepub fn execute<C: TpmCommandObject>(
&mut self,
command: &C,
sessions: &[TpmsAuthCommand],
) -> Result<(TpmResponseBody, TpmAuthResponses), DeviceError>
pub fn execute<C: TpmCommandObject>( &mut self, command: &C, sessions: &[TpmsAuthCommand], ) -> Result<(TpmResponseBody, TpmAuthResponses), DeviceError>
Performs the whole TPM command transmission process.
Errors
Returns Interrupted when
user interrupts the program.
Returns Io when an I/O operation
fails.
Returns Timeout when the
transmission timeouts.
Returns TpmProtocol when
either built command or parsed response is malformed.
Returns TpmRc when the chip
responses with a return code.
Sourcepub fn get_capability<T, F, N>(
&mut self,
cap: TpmCap,
property_start: u32,
count: u32,
extract: F,
next_prop: N,
) -> Result<Vec<T>, DeviceError>where
T: Copy,
F: for<'a> FnMut(&'a TpmuCapabilities) -> Result<&'a [T], DeviceError>,
N: Fn(&T) -> u32,
pub fn get_capability<T, F, N>(
&mut self,
cap: TpmCap,
property_start: u32,
count: u32,
extract: F,
next_prop: N,
) -> Result<Vec<T>, DeviceError>where
T: Copy,
F: for<'a> FnMut(&'a TpmuCapabilities) -> Result<&'a [T], DeviceError>,
N: Fn(&T) -> u32,
Fetches a complete list of capabilities from the TPM, handling pagination.
Errors
This function will return an error if the underlying execute call fails
or if the TPM returns a response of an unexpected type.
Sourcepub fn fetch_handles(&mut self, class: u32) -> Result<Vec<Handle>, DeviceError>
pub fn fetch_handles(&mut self, class: u32) -> Result<Vec<Handle>, DeviceError>
Retrieves all handles of a specific type from the TPM.
Errors
Returns a DeviceError if the get_capability_page call to the TPM device fails.
Sourcepub fn get_capability_page(
&mut self,
cap: TpmCap,
property: u32,
count: u32,
) -> Result<(bool, TpmsCapabilityData), DeviceError>
pub fn get_capability_page( &mut self, cap: TpmCap, property: u32, count: u32, ) -> Result<(bool, TpmsCapabilityData), DeviceError>
Fetches and returns one page of capabilities of a certain type from the TPM.
Errors
This function will return an error if the underlying execute call fails
or if the TPM returns a response of an unexpected type.
Sourcepub fn get_tpm_property(&mut self, property: TpmPt) -> Result<u32, DeviceError>
pub fn get_tpm_property(&mut self, property: TpmPt) -> Result<u32, DeviceError>
Reads a specific TPM property.
Errors
Returns a DeviceError if the capability or property is not found, or
if the get_capability call fails.
Sourcepub fn read_public(
&mut self,
handle: TpmHandle,
) -> Result<(TpmtPublic, Tpm2bName), DeviceError>
pub fn read_public( &mut self, handle: TpmHandle, ) -> Result<(TpmtPublic, Tpm2bName), DeviceError>
Reads the public area of a TPM object.
Errors
Returns a DeviceError if the underlying TPM2_ReadPublic command
execution fails or if the TPM returns a response of an unexpected type.
Sourcepub fn find_persistent(
&mut self,
target: &TpmtPublic,
) -> Result<Option<(TpmHandle, Tpm2bName)>, DeviceError>
pub fn find_persistent( &mut self, target: &TpmtPublic, ) -> Result<Option<(TpmHandle, Tpm2bName)>, DeviceError>
Finds a persistent handle by its public area.
Errors
Returns a DeviceError if fetching handles or reading public areas fails.
Sourcepub fn save_context(
&mut self,
save_handle: TpmHandle,
) -> Result<TpmsContext, DeviceError>
pub fn save_context( &mut self, save_handle: TpmHandle, ) -> Result<TpmsContext, DeviceError>
Saves the context of a transient object or session.
Errors
Returns a DeviceError if the underlying TPM2_ContextSave command
execution fails or if the TPM returns a response of an unexpected type.
Sourcepub fn load_context(
&mut self,
context: TpmsContext,
) -> Result<TpmHandle, DeviceError>
pub fn load_context( &mut self, context: TpmsContext, ) -> Result<TpmHandle, DeviceError>
Loads a TPM context and returns the handle.
Errors
Returns a DeviceError if the TPM2_ContextLoad command fails.
Sourcepub fn flush_context(&mut self, handle: TpmHandle) -> Result<(), DeviceError>
pub fn flush_context(&mut self, handle: TpmHandle) -> Result<(), DeviceError>
Flushes a transient object or session from the TPM and removes it from the cache.
Errors
Returns a DeviceError if the underlying TPM2_FlushContext command
execution fails.
Sourcepub fn flush_session(&mut self, context: TpmsContext) -> Result<(), DeviceError>
pub fn flush_session(&mut self, context: TpmsContext) -> Result<(), DeviceError>
Loads a session context and then flushes the resulting handle.
Errors
Returns DeviceError on ContextLoad or FlushContext failure.
Sourcepub fn start_session(
&mut self,
session_type: TpmSe,
auth_hash: TpmAlgId,
bind: TpmHandle,
) -> Result<(TpmStartAuthSessionResponse, Tpm2bNonce), DeviceError>
pub fn start_session( &mut self, session_type: TpmSe, auth_hash: TpmAlgId, bind: TpmHandle, ) -> Result<(TpmStartAuthSessionResponse, Tpm2bNonce), DeviceError>
Starts a new authorization session.
This function sends a TPM2_StartAuthSession command to the TPM and
returns the raw response, which can be used to construct a higher-level
session object.
Errors
Returns DeviceError on TPM command failure.
Sourcepub fn evict_control(
&mut self,
auth: TpmHandle,
object_handle: TpmHandle,
persistent_handle: TpmHandle,
sessions: &[TpmsAuthCommand],
) -> Result<(), DeviceError>
pub fn evict_control( &mut self, auth: TpmHandle, object_handle: TpmHandle, persistent_handle: TpmHandle, sessions: &[TpmsAuthCommand], ) -> Result<(), DeviceError>
Evicts a persistent object or makes a transient object persistent.
Errors
Returns DeviceError on TPM command failure.