run_impact

Function run_impact 

pub fn run_impact(db_dir: &Path, files: &[String]) -> Result<String, CliError>
Body of mushroomdb impact <db-dir> <file>....

The files named are taken to be the change, so each is reported and every partner that is one of them is marked modified.