Module git_projection_engine

Module git_projection_engine 

Git projection engine modules for interoperability with Git.

This module provides bidirectional conversion between Heddle state and Git projection state.

Re-exports

pub use git_core::GitProjection;
pub use git_core::GitProjectionError;
pub use git_core::GitProjectionResult;
pub use git_core::SyncMapping;
pub use git_core::WriteThroughOutcome;
pub use git_core::WriteThroughSkipReason;

Modules

git_core
Core Git Projection and Bridge Mirror operations.
git_export
Export Heddle states to Git commits functionality.
git_mapping
Persistence and discovery for Git Projection Mapping.
git_notes
Git notes attached at refs/notes/heddle carry Heddle state metadata (change_id, agent, confidence, status) without polluting the commit message — and so without changing the commit SHA.
git_reconstruct
Byte-exact git commit object serialization from a Heddle State (#566).
git_sync
Sync threads/markers for Git Projection Mapping.
git_util
Shared utilities and helpers for Git Projection operations.