pub fn export_current_thread(
bridge: &mut GitProjection<'_>,
thread: &str,
) -> GitProjectionResult<ExportStats>Expand description
Export one Heddle thread to its matching Git branch.
pub fn export_current_thread(
bridge: &mut GitProjection<'_>,
thread: &str,
) -> GitProjectionResult<ExportStats>Export one Heddle thread to its matching Git branch.