pub fn detect_binary_location() -> BinaryLocationExpand description
Decide how the MCP entry should invoke mushroomdb, from the real environment.
pub fn detect_binary_location() -> BinaryLocationDecide how the MCP entry should invoke mushroomdb, from the real environment.