Module key

Module key 

Structs

Alg
OtherPrimeInfo
Pkcs8AlgorithmIdentifier
Pkcs8PrivateKeyInfo
RsaPrivateKeyAsn1
A struct representing the full 9-field PKCS#1 RSAPrivateKey structure.
RsaPrivateKeyPkcs1V0
A struct representing an 8-field PKCS#1 RSAPrivateKey structure, for compatibility with encoders that omit the version field when it is 0.
Sec1EcPrivateKey
Tpm2shAlgId
A newtype wrapper to provide a project-specific Display implementation for TpmAlgId.
TpmAuthPolicy
A TPM authorization policy struct that is directly compatible with ASN.1 DER encoding.
TpmKey
A TPM key struct that is directly compatible with ASN.1 DER encoding.
TpmKeyTemplate
A template for creating a new TPM key object.
TpmPolicy
A TPM policy struct that is directly compatible with ASN.1 DER encoding.

Enums

AlgInfo
AnyKey
ExternalKey
KeyError
Tpm2shEccCurve
A local wrapper enum for TpmEccCurve to allow strum derives.

Constants

OID_ECDSA_WITH_SHA256
OID_ECDSA_WITH_SHA384
OID_ECDSA_WITH_SHA512
OID_EC_PUBLIC_KEY
OID_IMPORTABLE_KEY
OID_LOADABLE_KEY
OID_RSA_ENCRYPTION
OID_SEALED_DATA
OID_SHA1_WITH_RSA_ENCRYPTION
OID_SHA256_WITH_RSA_ENCRYPTION
OID_SHA384_WITH_RSA_ENCRYPTION
OID_SHA512_WITH_RSA_ENCRYPTION
SECP_256_R_1
SECP_384_R_1
SECP_521_R_1

Functions

ecc_to_public
Converts ECC public key bytes to a TpmtPublic structure.
format_alg_from_public
Formats a human-readable algorithm string from a TpmtPublic structure.
parse_ecc_from_der
Parses a SEC1 DER-encoded ECC private key.
parse_rsa_from_der
Parses a DER-encoded RSA private key, supporting only the PKCS#1 format.
rsa_to_public
Converts an RsaPrivateKey to a TpmtPublic structure.