pub struct TpmKey {
pub key_type: ObjectIdentifier,
pub empty_auth: Option<bool>,
pub policy: Option<Vec<TpmPolicy>>,
pub secret: Option<OctetString>,
pub auth_policy: Option<Vec<TpmAuthPolicy>>,
pub description: Option<Utf8String>,
pub rsa_parent: Option<bool>,
pub parent: u32,
pub pub_key: OctetString,
pub priv_key: OctetString,
}Expand description
A TPM key struct that is directly compatible with ASN.1 DER encoding.
Fields
key_type: ObjectIdentifierempty_auth: Option<bool>policy: Option<Vec<TpmPolicy>>secret: Option<OctetString>auth_policy: Option<Vec<TpmAuthPolicy>>description: Option<Utf8String>rsa_parent: Option<bool>parent: u32pub_key: OctetStringpriv_key: OctetStringImplementations
Sourceimpl TpmKey
impl TpmKey
Sourcepub fn new(
device: &mut Device,
context: &mut ContextCache<'_>,
auth_list: &[Auth],
auth: &Auth,
parent_handle: TpmHandle,
template: &TpmKeyTemplate<'_>,
) -> Result<Self, KeyError>
pub fn new( device: &mut Device, context: &mut ContextCache<'_>, auth_list: &[Auth], auth: &Auth, parent_handle: TpmHandle, template: &TpmKeyTemplate<'_>, ) -> Result<Self, KeyError>
Creates a new TpmKey by executing a TPM2_Create command.
Errors
Returns a KeyError if any of the TPM structures cannot be serialized or the command fails.
Sourcepub fn from_external_key(
device: &mut Device,
parent_handle: TpmHandle,
external_key: &ExternalKey,
rng: &mut (impl RngCore + CryptoRng),
handles: &[u32],
auth_list: &[Auth],
context: &mut ContextCache<'_>,
) -> Result<Self, KeyError>
pub fn from_external_key( device: &mut Device, parent_handle: TpmHandle, external_key: &ExternalKey, rng: &mut (impl RngCore + CryptoRng), handles: &[u32], auth_list: &[Auth], context: &mut ContextCache<'_>, ) -> Result<Self, KeyError>
Imports an external key under a TPM parent, creating a new TpmKey.
Errors
Returns an error if the TPM import operation fails.
Remarks on symmetricAlg
In TPM2_Import the symmetricAlg parameter defines the cipher for the
inner wrapper of the duplicate blob.
The key import process differences for ECC and RSA parents:
- ECC: the import uses ECDH with AES-CFB as the symmetric algorithm.
- RSA: the import uses RSA-OAEP to encrypt a seed, which passed in
the
inSymSeedcommand parameter,encryptionKeyis zero-length vector andsymmetricAlgmust be set toTPM_ALG_NULL.
Sourcepub fn public(&self) -> Result<Tpm2bPublic, KeyError>
pub fn public(&self) -> Result<Tpm2bPublic, KeyError>
Parses and returns the public area of the key.
Errors
Returns a KeyError if the public key bytes cannot be parsed.
Sourcepub fn to_pem(&self) -> Result<String, KeyError>
pub fn to_pem(&self) -> Result<String, KeyError>
Serialize TPM key to PEM.
Errors
Returns CliError if the key’s OID or other fields cannot be encoded to DER.
Sourcepub fn to_der(&self) -> Result<Vec<u8>, KeyError>
pub fn to_der(&self) -> Result<Vec<u8>, KeyError>
Serialize TPM key to DER bytes.
Errors
Returns CliError if the key’s OID or other fields cannot be encoded to DER.