Module software

Module software 

A pure software implementation of a policy session for dry-run calculations.

Structs

SoftwarePolicySession
A session that simulates TPM policy digest calculations in software.

Functions

update_policy_digest
Updates a policy digest with a new command, mimicking the TPM’s internal hashing. This can be shared between the software session and the mock TPM.