pub struct PresetValidationReportV1 {
pub schema_version: u32,
pub valid: bool,
pub path: PathBuf,
pub summary: PresetValidationSummary,
pub diagnostics: Vec<PresetDiagnostic>,
pub categories: Vec<PresetCategoryValidation>,
}Fields
schema_version: u32valid: boolpath: PathBufsummary: PresetValidationSummarydiagnostics: Vec<PresetDiagnostic>categories: Vec<PresetCategoryValidation>Trait Implementations
Sourceimpl Clone for PresetValidationReportV1
impl Clone for PresetValidationReportV1
Sourcefn clone(&self) -> PresetValidationReportV1
fn clone(&self) -> PresetValidationReportV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PresetValidationReportV1
impl Debug for PresetValidationReportV1
impl Eq for PresetValidationReportV1
Sourceimpl JsonSchema for PresetValidationReportV1
impl JsonSchema for PresetValidationReportV1
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PresetValidationReportV1
impl PartialEq for PresetValidationReportV1
Sourceimpl Serialize for PresetValidationReportV1
impl Serialize for PresetValidationReportV1
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for PresetValidationReportV1