Remote configuration management.
Remote aliases remain repository-scoped and live in .heddle/remotes.toml.
Structs
Enums
- Remote
Error - Remote
Target - A remote target - either a network address or a local path.
Functions
- credential_
key_ from_ remote_ url - Extract the hostname (credential store key) from a remote URL string.
- resolve_
remote - Resolve a remote argument (name or URL) into a concrete target.
- resolve_
remote_ with_ key - Resolve a remote argument (name or URL) into a concrete target, also returning the raw URL string that can be used as a credential store key.