resolve_remote_with_key

Function resolve_remote_with_key 

pub fn resolve_remote_with_key(
    repo: &Repository,
    remote_arg: Option<&str>,
) -> Result<(RemoteTarget, Option<String>), RemoteError>
Resolve a remote argument (name or URL) into a concrete target, also returning the raw URL string that can be used as a credential store key.