Module semantic

Module semantic 

Semantic facade for the CLI crate.

Structs

SemanticCheckOnlyResult
Result of the cheap semantic no-op check.
SemanticDiffOptions
Options for semantic diff analysis.
SemanticDiffResult
SemanticSummaryResult
Aggregated semantic summary without the full detailed change list.

Enums

SemanticCheckStatus
Result classification for the cheap semantic check path.
SemanticFallbackReason
Conservative reason that semantic analysis skipped or degraded work.

Functions

semantic_check_only
semantic_check_only_worktree
semantic_diff
semantic_diff_summary
semantic_diff_summary_worktree
semantic_diff_worktree