extract_block_with_newline

Function extract_block_with_newline 

pub fn extract_block_with_newline<'a>(
    content: &'a str,
    sentinel: &Sentinel<'_>,
) -> Option<&'a str>
Like find_block, but also includes one trailing '\n' immediately after the end marker if present. The end marker is searched for only after the start marker, so an end marker that appears before the start marker is not matched.