find_block

Function find_block 

pub fn find_block<'a>(
    content: &'a str,
    sentinel: &Sentinel<'_>,
) -> Option<&'a str>
Returns the substring from the start marker through the end marker (inclusive), or None if either marker is missing. Does not include any trailing newline after the end marker.