Module session

Module session 

For sessions, context managements works as follows:

  1. TPM2_ContextSave transforms an active session into saved session, which gets a handle from the same address range as HMAC sessions.
  2. TPM2_ContextLoad transforms a saved session into active session, and session regains the handle assigned upon creation.

Consequences:

  1. TPM2_FlushContext must not be applied after TPM2_ContextSave.
  2. TPM2_FlushContext can be only applied to a loaded session.

Structs

Session
Manages the state of an active authorization session.
SessionCache

Enums

SessionError