pub struct SessionCache {
pub sessions: HashMap<String, Session>,
pub dirty: HashSet<String>,
pub sessions_dir: PathBuf,
}Fields
sessions: HashMap<String, Session>dirty: HashSet<String>sessions_dir: PathBufImplementations
Sourceimpl SessionCache
impl SessionCache
Sourcepub fn load_sessions(&mut self) -> Result<(), SessionError>
pub fn load_sessions(&mut self) -> Result<(), SessionError>
Populates the session map by reading all available session files from the cache directory.
Errors
Returns SessionError on I/O failure.
Sourcepub fn refresh_sessions(
&mut self,
device: &mut Device,
) -> Result<(), SessionError>
pub fn refresh_sessions( &mut self, device: &mut Device, ) -> Result<(), SessionError>
Validates all sessions at startup, and removes expired sessions from the previous power cycle.
Errors
Returns an aggregate DeviceError if any non-recoverable errors occur.
Individual session failures are logged as warnings.
Sourcepub fn save(&mut self) -> Result<(), SessionError>
pub fn save(&mut self) -> Result<(), SessionError>
Saves all sessions marked as dirty to their respective files.
Errors
Returns an error on serialization or I/O failure.
Sourcepub fn remove(&mut self, uri: &str) -> Result<Option<Session>, SessionError>
pub fn remove(&mut self, uri: &str) -> Result<Option<Session>, SessionError>
Removes a session from the map and deletes its file from disk. This operation is idempotent.
Errors
Returns SessionError on I/O failure (e.g. permissions).
Sourcepub fn reset(&mut self) -> Result<(), SessionError>
pub fn reset(&mut self) -> Result<(), SessionError>
Removes all sessions from the map and deletes their files from disk.
Errors
Returns SessionError::Io on I/O failure.
Sourcepub fn get(&self, uri: &str) -> Result<&Session, SessionError>
pub fn get(&self, uri: &str) -> Result<&Session, SessionError>
Gets an immutable reference to a session.
Errors
Returns SessionError::NotFound if no session is found.
Sourcepub fn get_mut(&mut self, uri: &str) -> Result<&mut Session, SessionError>
pub fn get_mut(&mut self, uri: &str) -> Result<&mut Session, SessionError>
Gets a mutable reference to a session, marks it as dirty.
Errors
Returns SessionError::NotFound if no session is found.
Sourcepub fn prepare_sessions(
&mut self,
device: &mut Device,
auth_list: &[Auth],
) -> Result<Vec<u32>, SessionError>
pub fn prepare_sessions( &mut self, device: &mut Device, auth_list: &[Auth], ) -> Result<Vec<u32>, SessionError>
Loads session contexts if they are not already active.
Errors
Returns a SessionError if a session URI is invalid or if loading a TPM
context fails.
Sourcepub fn build_auth_area<C: TpmCommandObject>(
&self,
device: &mut Device,
command: &C,
handles: &[u32],
auth_list: &[Auth],
) -> Result<(Vec<TpmsAuthCommand>, Vec<u32>), SessionError>
pub fn build_auth_area<C: TpmCommandObject>( &self, device: &mut Device, command: &C, handles: &[u32], auth_list: &[Auth], ) -> Result<(Vec<TpmsAuthCommand>, Vec<u32>), SessionError>
Builds the authorization area for a command.
Errors
Returns a SessionError if a session URI is not found, or if building
any part of the authorization command fails.
Sourcepub fn teardown_sessions(
&mut self,
device: &mut Device,
session_handles: &[u32],
auth_responses: &TpmAuthResponses,
) -> Result<(), SessionError>
pub fn teardown_sessions( &mut self, device: &mut Device, session_handles: &[u32], auth_responses: &TpmAuthResponses, ) -> Result<(), SessionError>
Finalizes sessions after a command executes.
Errors
Returns a SessionError if a session URI is not found, or if
saving/flushing the updated TPM context fails.