pub async fn load_active_target(
config: &Config,
target: ShellTarget<'_>,
) -> Result<Vec<ShellCategory>>Expand description
Select and validate one shell lifecycle target from the active preset namespace.
pub async fn load_active_target(
config: &Config,
target: ShellTarget<'_>,
) -> Result<Vec<ShellCategory>>Select and validate one shell lifecycle target from the active preset namespace.