Top-level shine install/uninstall <target> shims: they resolve canonical
or unambiguous preset targets and delegate to the corresponding handler.
Top-level shine install/uninstall <target> shims: they resolve canonical
or unambiguous preset targets and delegate to the corresponding handler.