pub struct ConfigSection {Show 22 fields
pub skip_core_tasks: Option<bool>,
pub modify_core_tasks: Option<ModifyConfig>,
pub init_task: Option<String>,
pub end_task: Option<String>,
pub on_error_task: Option<String>,
pub legacy_migration_task: Option<String>,
pub additional_profiles: Option<Vec<String>>,
pub min_version: Option<String>,
pub default_to_workspace: Option<bool>,
pub skip_git_env_info: Option<bool>,
pub skip_rust_env_info: Option<bool>,
pub skip_crate_env_info: Option<bool>,
pub reduce_output: Option<bool>,
pub time_summary: Option<bool>,
pub load_cargo_aliases: Option<bool>,
pub disable_install: Option<bool>,
pub main_project_member: Option<String>,
pub load_script: Option<ScriptValue>,
pub linux_load_script: Option<ScriptValue>,
pub windows_load_script: Option<ScriptValue>,
pub mac_load_script: Option<ScriptValue>,
pub unstable_features: Option<IndexSet<UnstableFeature>>,
}Expand description
Holds the configuration found in the makefile toml config section.
Fields
skip_core_tasks: Option<bool>If true, the default core tasks will not be loaded
modify_core_tasks: Option<ModifyConfig>Modify core tasks config
init_task: Option<String>Init task name which will be invoked at the start of every run
end_task: Option<String>End task name which will be invoked at the end of every run
on_error_task: Option<String>The name of the task to run in case of any error during the invocation of the flow
legacy_migration_task: Option<String>The name of the task which runs legacy migration flows
additional_profiles: Option<Vec<String>>Additional profile names to load
min_version: Option<String>Minimum cargo-make/makers version
default_to_workspace: Option<bool>The task.workspace default value
skip_git_env_info: Option<bool>do not load git env info (save on perf)
skip_rust_env_info: Option<bool>do not load rust env info (save on perf)
skip_crate_env_info: Option<bool>do not load current crate env info (save on perf)
reduce_output: Option<bool>True to reduce console output for non CI execution
time_summary: Option<bool>True to print time summary at the end of the flow
load_cargo_aliases: Option<bool>Automatically load cargo aliases as cargo-make tasks
disable_install: Option<bool>If true (default false) disable all automatic/defined installation instructions
main_project_member: Option<String>The project information member (used by workspaces)
load_script: Option<ScriptValue>Invoked while loading the descriptor file but before loading any extended descriptor
linux_load_script: Option<ScriptValue>acts like load_script if runtime OS is Linux (takes precedence over load_script)
windows_load_script: Option<ScriptValue>acts like load_script if runtime OS is Windows (takes precedence over load_script)
mac_load_script: Option<ScriptValue>acts like load_script if runtime OS is Mac (takes precedence over load_script)
unstable_features: Option<IndexSet<UnstableFeature>>Enables unstable cargo-make features
Implementations
Sourceimpl ConfigSection
impl ConfigSection
Sourcepub fn new() -> ConfigSection
pub fn new() -> ConfigSection
Creates and returns a new instance.
Sourcepub fn apply(self: &mut ConfigSection, modify_config: &ModifyConfig)
pub fn apply(self: &mut ConfigSection, modify_config: &ModifyConfig)
Apply modifications
Sourcepub fn extend(self: &mut ConfigSection, extended: &mut ConfigSection)
pub fn extend(self: &mut ConfigSection, extended: &mut ConfigSection)
Sourcepub fn get_load_script(self: &ConfigSection) -> Option<ScriptValue>
pub fn get_load_script(self: &ConfigSection) -> Option<ScriptValue>
Returns the load script based on the current platform