Struct cli::types::EnvValueDecode [−][src]
pub struct EnvValueDecode {
pub source: String,
pub default_value: Option<String>,
pub mapping: HashMap<String, String>,
}Expand description
Env value provided by decoding other values
Fields
source: StringThe source value (can be an env expression)
default_value: Option<String>The default value in case no decode mapping was found, if not provided it will default to the source value
mapping: HashMap<String, String>The decoding mapping