Struct cli::types::ModifyConfig [−][src]
Holds properties to modify the core tasks
Fields
private: Option<bool>If true, all core tasks will be set to private (default false)
namespace: Option<String>If set to some value, all core tasks are modified to: namespace::name for example default::build
Implementations
Returns true if config modifications is needed based on the current state
Returns the namespace prefix for task names