skip_requirements_check

Function skip_requirements_check 

pub async fn skip_requirements_check() -> bool
Do not remove this check. Provides a way to skip the server glibc requirements check from outside the install flow. A system process can create this file before the server is downloaded and installed.