VtpmCache

Struct VtpmCache 

pub struct VtpmCache<'a> {
    pub contexts: HashMap<u32, Box<dyn VtpmContext>>,
    pub handles: HashMap<u32, TpmHandle>,
    /* private fields */
}

Fields

contexts: HashMap<u32, Box<dyn VtpmContext>>handles: HashMap<u32, TpmHandle>

Implementations

Source

impl<'a> VtpmCache<'a>

pub fn new(cache_dir: &'a Path) -> Result<Self, VtpmError>

Creates a new cache and loads existing contexts from disk.

Errors

Returns a VtpmError if loading contexts from the cache directory fails.

pub fn find_by_public(&self, public: &TpmtPublic) -> Option<&VtpmKey>

Finds a VTPM key corresponding to a TpmtPublic,

pub fn find_by_phandle( &self, device: &mut Device, phandle: u32, ) -> Result<&VtpmKey, VtpmError>

Finds a VTPM key corresponding to a physical handle.

Reads the public area of a physical TPM handle and searches the cache for a loaded key with a matching public area. If found, it returns the corresponding virtual handle.

Errors

Returns ContextNotFound when context is not found. Returns Device when TPM2_ReadPublic fails.

pub fn find_by_vhandle(&self, vhandle: u32) -> Result<&VtpmKey, VtpmError>

Finds a VTPM key corresponding to a virtual handle.

Reads the public area of a physical TPM handle and searches the cache for a loaded key with a matching public area. If found, it returns the corresponding virtual handle.

Errors

Returns ContextNotFound when context is not found.

pub fn save(&mut self) -> Result<(), VtpmError>

Saves all dirty contexts to disk.

Errors

Returns a VtpmError if saving any of the dirty contexts fails.

pub fn remove( &mut self, device: &mut Device, vhandle: u32, ) -> Result<(), VtpmError>

Removes a context from the cache and performs necessary cleanup.

Errors

Returns a VtpmError if deleting the context fails.

pub fn track(&mut self, handle: TpmHandle) -> Result<(), VtpmError>

Tracks a transient handle for automatic cleanup.

Errors

Returns a VtpmError::AlreadyTracked if the handle is already being tracked.

pub fn untrack(&mut self, handle: u32)

Removes a handle from the tracking list.

pub fn teardown(&mut self, device: Option<Rc<RefCell<Device>>>)

Finalizes the cache, saving dirty contexts and flushing handles.

pub fn save_context( &mut self, device: &mut Device, handle: TpmHandle, public: &Tpm2bPublic, parent_public: &Tpm2bPublic, ) -> Result<u32, VtpmError>

Saves a new key context.

Errors

Returns a VtpmError if saving the context to the TPM or writing the cache file fails.

pub fn add_session(&mut self, session: VtpmSession) -> u32

Adds a session to the cache.

pub fn mark_dirty(&mut self, vhandle: u32)

Marks a context as dirty.

pub fn get_session(&self, vhandle: u32) -> Option<&VtpmSession>

Gets an immutable reference to a session.

pub fn get_mut_session(&mut self, vhandle: u32) -> Option<&mut VtpmSession>

Gets a mutable reference to a session.

pub fn key_iter(&self) -> impl Iterator<Item = (&u32, &VtpmKey)>

Returns an iterator over the key contexts.

pub fn prepare_sessions( &mut self, device: &mut Device, auth_list: &[Auth], ) -> Result<Vec<TpmHandle>, VtpmError>

Prepares sessions by loading them into the TPM.

Errors

Returns a VtpmError if a session is not found or loading its context fails.

pub fn teardown_sessions( &mut self, device: &mut Device, session_vhandles: &HashSet<u32>, auth_responses: &TpmAuthResponses, ) -> Result<(), VtpmError>

Tears down sessions by saving their updated contexts.

Errors

Returns a VtpmError if a session is not found or if saving/flushing the context fails.