Crate cli

Crate cli 

Modules

auth
Handles parsing and representation of authorization data for TPM commands.
cli
command
crypto
This file contains cryptographic algorithms shared by tpm2sh and MockTPM.
device
handle
io
job
key
pcr
Abstractions and logic for handling Platform Configuration Registers (PCRs).
policy
This module contains the parser and executor for the unified policy language.
print
spinner
Displays a spinner in the terminal.
template
vtpm
Manages caching for TPM keys and sessions.

Statics

TEARDOWN
A global flag to signal graceful teardown of the application.

Functions

parse_hex_u32
Parses a hexadecimal string with an optional “0x” prefix into a u32.
write_object
Serialize a type implementing TpmBuild type into Vec<u8>.