Crate cli
Source - cli
- command
- context
- Manages the execution context, including sessions and transient object handles.
- convert
- crypto
- This file contains cryptographic algorithms shared by tpm2sh and
MockTPM. - device
- key
- pcr
- Abstractions and logic for handling Platform Configuration Registers (PCRs).
- policy
- This module contains the parser and executor for the unified policy language.
- print
- session
- For sessions, context managements works as follows:
- template
- transport
- uri
- x509
- TEARDOWN
- A global flag to signal graceful teardown of the application.