Module git_core

Module git_core 

Core Git bridge types and operations.

Structs

GitBridge
Git bridge for Heddle repository.
SyncMapping
Mapping between Heddle ChangeIds and Git commit object IDs.

Enums

GitBridgeError
Errors specific to Git bridge operations.
WriteThroughOutcome
WriteThroughSkipReason

Functions

clone_url_to_bare
Clone a remote git URL into dest as a bare repository, fetching all branches and tags. Mirrors the gix recipe used by fetch_network_remote but starts from an empty init_bare rather than an existing repo.
copy_local_repo_to_bare
Copy a local Git repository into a bare repository without invoking Git transport helpers. This is the local-path clone fast path used by the OSS Git-overlay workflow when the user does not have git installed.

Type Aliases

GitResult
Type alias for Git bridge results.