Core Git bridge types and operations.
Structs
- GitBridge
- Git bridge for Heddle repository.
- Sync
Mapping - Mapping between Heddle ChangeIds and Git commit object IDs.
Enums
- GitBridge
Error - Errors specific to Git bridge operations.
- Write
Through Outcome - Write
Through Skip Reason
Functions
- clone_
url_ to_ bare - Clone a remote git URL into
destas a bare repository, fetching all branches and tags. Mirrors the gix recipe used byfetch_network_remotebut starts from an emptyinit_barerather than an existing repo. - copy_
local_ repo_ to_ bare - Copy a local Git repository into a bare repository without invoking Git
transport helpers. This is the local-path clone fast path used by the OSS
Git-overlay workflow when the user does not have
gitinstalled.
Type Aliases
- GitResult
- Type alias for Git bridge results.