CLI command implementations.
Structs
Constants
- REGISTERED_
VERBS - All verbs whose
--jsonoutput has a schema mirror.
Functions
- agent_
api_ schema - Return the combined JSON schema for the public agent-API output
types. Snapshot-tested in
tests/agent_api_schema.rsso any breaking change to the wire shape is caught at PR review. - cmd_
abort - cmd_
actor_ done - cmd_
actor_ explain - cmd_
actor_ list - cmd_
actor_ show - cmd_
actor_ spawn - cmd_
agent - cmd_
agent_ capture heddle agent capture --session <SID>: a session-validated alias forheddle capturethat proves the caller still owns the reservation it claims to before writing.- cmd_
agent_ heartbeat - cmd_
agent_ list - cmd_
agent_ ready heddle agent ready --session <SID>: a session-validated alias forheddle readythat ensures the caller still owns the reservation it’s trying to mark ready.- cmd_
agent_ release - cmd_
agent_ reserve - cmd_
attempt - cmd_
bisect - cmd_
blame - cmd_
bridge_ git - Execute bridge subcommands.
- cmd_
capture_ split - cmd_
checkpoint - cmd_
cherry_ pick - cmd_
clean - cmd_
clone - cmd_
collapse - Collapse (squash) multiple states into a single state.
- cmd_
compare - Compare two states.
- cmd_
completion - cmd_
conflict - cmd_
context_ audit - cmd_
context_ check - cmd_
context_ edit - cmd_
context_ get - cmd_
context_ history - cmd_
context_ list - cmd_
context_ rm - cmd_
context_ set - Set a context annotation on a file path or state target.
- cmd_
context_ suggest - cmd_
context_ supersede - cmd_
continue - cmd_
daemon_ serve - cmd_
daemon_ status - cmd_
daemon_ stop - Post-condition contract for
cmd_daemon_stop: when this returnsOk(())after a live-daemon shutdown, the caller may rely on all four of the following being true: - cmd_
delegate - cmd_
diagnose - cmd_
diff - cmd_
discuss - cmd_
doctor_ docs - Public entrypoint wired from
main.rs. - cmd_
doctor_ schemas - Public entrypoint for
heddle doctor schemas. - cmd_
fetch - cmd_
fork - Create a fork (exploration branch) from the current or specified state.
- cmd_
fsck - cmd_gc
- cmd_
git_ overlay_ guide - cmd_
goto - cmd_
harness_ bridge - cmd_
hook - cmd_
index - cmd_
init - cmd_
integration - cmd_log
- cmd_
maintenance - cmd_
marker - cmd_
merge - cmd_
monitor - cmd_
pull - Execute pull command.
- cmd_
purge - cmd_
push - Execute push command.
- cmd_
query - cmd_
ready - cmd_
rebase - cmd_
redact - cmd_
redo - cmd_
remote - Execute remote command.
- cmd_
resolve - cmd_
retro - cmd_
revert - cmd_
review - cmd_run
- cmd_
schemas - Public entrypoint for
heddle schemas <verb> [--json]. - cmd_
semantic - Top-level dispatch for
heddle semantic <subcommand>. - cmd_
session_ end - cmd_
session_ list - cmd_
session_ segment - cmd_
session_ show - cmd_
session_ start - cmd_
ship - cmd_
show - cmd_
snapshot - cmd_
start - cmd_
stash - cmd_
status - cmd_
store - cmd_
sync - cmd_
sync_ smart - cmd_
thread - cmd_
thread_ absorb - cmd_
thread_ move - cmd_
thread_ resolve - cmd_
thread_ show - cmd_
transaction - cmd_try
- cmd_
undo - cmd_
version - cmd_
watch - Top-level entry point. Threading-wise:
- cmd_
workspace - cmd_
workspace_ show - maybe_
prompt_ init_ install - schema_
for_ verb - Generate the schema for
verb. ReturnsNoneif no schema is registered.