Manages the execution context, including sessions and transient object handles.
Design Invariants
To ensure predictable failure modes (i.e., failing on capacity limits rather
than opaque I/O errors from the TPM), this module upholds the invariant that
all created transient object handles must be tracked by a Context object.
This makes the Context the sole owner of all temporary resources, which are
guaranteed to be flushed at the end of the context’s lifecycle.
Structs
- Context
- A RAII guard for a loaded TPM context handle, ensuring it’s flushed on drop.
- Context
Cache - Context
Iterator - An iterator over the live, loaded contexts from the context store.
Enums
- Context
Error - Context
Item - The item yielded by the
ContextIterator.