Structs
Enums
- Auth
- Represents an authorization method for a command.
- Device
Error
Constants
Traits
- TpmCommand
Object - A type-erased object safe TPM command object
Functions
- with_
device - Executes a closure with a mutable reference to a
Device.
Type Aliases
- Auth
List - A type alias for a list of authentications, to attach methods.