Device

Struct Device 

pub struct Device { /* private fields */ }

Implementations

Source

impl Device

pub fn new( transport: impl Transport + 'static, log_format: LogFormat, ) -> Result<Self, DeviceError>

Creates a new TPM device from an owned transport.

Errors

Returns an error if the system poller cannot be created.

pub fn add_name_to_cache(&mut self, handle: u32, name: Tpm2bName)

Adds a transient handle’s name to the internal cache.

pub fn execute<C: TpmCommandObject>( &mut self, command: &C, sessions: &[TpmsAuthCommand], ) -> Result<(TpmResponseBody, TpmAuthResponses), DeviceError>

Sends a command to the TPM and waits for the response.

Errors

This function will return an error if building the command fails, I/O with the device fails, or the TPM itself returns an error.

pub fn get_all_algorithms( &mut self, ) -> Result<Vec<(TpmAlgId, String)>, DeviceError>

Retrieves all supported algorithms from the TPM by probing its capabilities.

Errors

Returns a DeviceError if querying the TPM fails.

pub fn get_all_hashes(&mut self) -> Result<Vec<String>, DeviceError>

Retrieves all supported hash algorithms from the TPM.

Errors

Returns a DeviceError if querying the TPM fails.

pub fn get_all_handles( &mut self, handle_type: u32, ) -> Result<Vec<u32>, DeviceError>

Retrieves all handles of a specific type from the TPM.

Errors

Returns a DeviceError if the get_capability call to the TPM device fails.

pub fn get_capability( &mut self, cap: TpmCap, property: u32, count: u32, ) -> Result<(bool, TpmsCapabilityData), DeviceError>

Fetches and returns one page of capabilities of a certain type from the TPM.

Errors

This function will return an error if the underlying execute call fails or if the TPM returns a response of an unexpected type.

pub fn get_tpm_property(&mut self, property: TpmPt) -> Result<u32, DeviceError>

Reads a specific TPM property.

Errors

Returns a DeviceError if the capability or property is not found, or if the get_capability call fails.

pub fn read_public( &mut self, handle: TpmHandle, ) -> Result<(TpmtPublic, Tpm2bName), DeviceError>

Reads the public area of a TPM object.

Errors

Returns a DeviceError if the underlying TPM2_ReadPublic command execution fails or if the TPM returns a response of an unexpected type.

pub fn save_context(&mut self, handle: u32) -> Result<TpmsContext, DeviceError>

Saves the context of a transient object or session.

Errors

Returns a DeviceError if the underlying TPM2_ContextSave command execution fails or if the TPM returns a response of an unexpected type.

pub fn load_context(&mut self, context: TpmsContext) -> Result<u32, DeviceError>

Loads a TPM context and returns the handle.

Errors

Returns a DeviceError if the TPM2_ContextLoad command fails.

pub fn flush_context(&mut self, handle: u32) -> Result<(), DeviceError>

Flushes a transient object or session from the TPM.

Errors

Returns a DeviceError if the underlying TPM2_FlushContext command execution fails.

pub fn flush_session(&mut self, context: TpmsContext) -> Result<(), DeviceError>

Loads a session context and then flushes the resulting handle.

Errors

Returns DeviceError on ContextLoad or FlushContext failure.

pub fn start_session( &mut self, session_type: TpmSe, auth_hash: TpmAlgId, ) -> Result<(TpmStartAuthSessionResponse, Tpm2bNonce), DeviceError>

Starts a new authorization session.

This function sends a TPM2_StartAuthSession command to the TPM and returns the raw response, which can be used to construct a higher-level session object.

Errors

Returns DeviceError on TPM command failure.