pub fn detect_binary_location() -> BinaryLocationExpand description
Decide how the MCP entry should invoke mushroomdb, from the real environment: PATH lookup first, else the current executable.
pub fn detect_binary_location() -> BinaryLocationDecide how the MCP entry should invoke mushroomdb, from the real environment: PATH lookup first, else the current executable.