pub fn detect_mcp_command(opts: &InstallOpts) -> McpCommandExpand description
Decide how the MCP entry should invoke mushroomdb, from the options and the real environment.
pub fn detect_mcp_command(opts: &InstallOpts) -> McpCommandDecide how the MCP entry should invoke mushroomdb, from the options and the real environment.