This module contains the parser and executor for the unified policy language.
Re-exports
Modules
- software
- A pure software implementation of a policy session for dry-run calculations.
- tpm
- A policy session that interacts directly with a TPM device.
Enums
- Expression
- The Abstract Syntax Tree (AST) for the unified policy language.
- Policy
Error
Traits
- Policy
Session - An abstract interface for a session that can have a policy applied to it.
Functions
- execute_
policy - Traverses a policy AST and applies the commands to a session object.
- parse
- Parses an expression string, ensuring the entire input is consumed.
- populate_
pcr_ digests - Recursively traverses a policy AST and populates any missing PCR digests from a provided map.