A pure software implementation of a policy session for dry-run calculations.
Structs
- Software
Policy Session - A session that simulates TPM policy digest calculations in software.
Functions
- update_
policy_ digest - Updates a policy digest with a new command, mimicking the TPM’s internal hashing. This can be shared between the software session and the mock TPM.