Module remote

Module remote 

Remote configuration management.

Remote aliases remain repository-scoped and live in .heddle/remotes.toml.

Structs

Remote
RemoteConfig
RemotesFile

Enums

RemoteError
RemoteTarget
A remote target - either a network address or a local path.

Functions

credential_key_from_remote_url
Extract the hostname (credential store key) from a remote URL string.
resolve_remote
Resolve a remote argument (name or URL) into a concrete target.
resolve_remote_with_key
Resolve a remote argument (name or URL) into a concrete target, also returning the raw URL string that can be used as a credential store key.

Type Aliases

Result