For sessions, context managements works as follows:
TPM2_ContextSavetransforms an active session into saved session, which gets a handle from the same address range as HMAC sessions.TPM2_ContextLoadtransforms a saved session into active session, and session regains the handle assigned upon creation.
Consequences:
TPM2_FlushContextmust not be applied afterTPM2_ContextSave.TPM2_FlushContextcan be only applied to a loaded session.
Structs
- Session
- Manages the state of an active authorization session.
- Session
Cache