Modules
- metadata
- Thin CLI adapter for Core-owned Shell preset metadata and target parsing.
Structs
Enums
Constants
Functions
- get_
shell - get_
shell_ config_ path - handle_
completion_ install - handle_
info - handle_
init_ template - handle_
install - handle_
install_ approved - handle_
install_ dry_ run - Resolve and validate a shell installation plan without extracting presets, rendering templates, creating links, updating manifests, or editing shell profiles.
- handle_
list - handle_
recover_ approved - handle_
uninstall - handle_
uninstall_ approved - handle_
upgrade_ installed - handle_
upgrade_ installed_ target