Module shells

Module shells 

Modules

metadata

Structs

ShellUpgradeReport

Enums

ShellType

Constants

SENTINEL_START

Functions

get_shell
get_shell_config_path
handle_completion_install
handle_info
handle_init_template
handle_install
handle_install_dry_run
Resolve and validate a shell installation plan without extracting presets, rendering templates, creating links, updating manifests, or editing shell profiles.
handle_list
handle_uninstall
handle_upgrade_installed
handle_upgrade_installed_target